@@ -1,9 +1,9 @@
 #! python3  # noqa: E265
 
 # submodules
-from .matchers import (
-    MATCHER_FORMAT,
+from .matchers import (  # noqa: F401
+    MATCHER_FORMAT,  # noqa: F401
     MATCHER_GEOMETRY,  # noqa: F401
-    match_coordinate_system,
+    match_coordinate_system,  # noqa: F401
 )
 from .lookup_to_isogeo import LookupToIsogeo  # noqa: F401
