@@ -44,13 +44,23 @@ class MetadataJsonReader:
     :param Union[str, Path, BufferedIOBase, bytes] in_json: path to the json file to read.
     """
 
+    # global options to pass to open method
+    # see: https://docs.python.org/fr/3/library/functions.html#open
+    ENCODING_DEFAULT = "UTF-8"  # used as default encoding
+    ENCODING_FALLBACK = "latin1"  # used as fallback encoding
+    ENCODING_ERRORS_MODE = "replace"  # used to handle encoding errors
+
     def __init__(self, in_json: Union[str, Path, BufferedIOBase, bytes]):
         """Instanciating Isogeo Metadata JSON Reader."""
         # check and get JSON path
         if isinstance(in_json, (str, Path)):
             self.input_json = self.check_json_file(in_json)
             # extract data from input file
-            with self.input_json.open(mode="r") as bytes_data:
+            with self.input_json.open(
+                mode="r",
+                encoding=self.ENCODING_DEFAULT,
+                errors=self.ENCODING_ERRORS_MODE,
+            ) as bytes_data:
                 self.json_data = json.load(bytes_data)
         elif isinstance(in_json, BufferedIOBase):
             self.input_json = self.check_json_buffer(in_json)
@@ -98,12 +108,28 @@ class MetadataJsonReader:
             raise IOError("json file isn't readable: {}".format(json_path))
 
         # check integrity
-        with json_path.open(mode="r") as in_json_file:
+        with json_path.open(
+            mode="r", encoding=self.ENCODING_DEFAULT, errors=self.ENCODING_ERRORS_MODE
+        ) as in_json_file:
             try:
                 json.load(in_json_file)
-            except JSONDecodeError as exc:
-                logger.error(msg="JSON file is invalid: {}".format(json_path.resolve()))
-                raise exc
+            except JSONDecodeError as err:
+                logger.error("JSON file is invalid: {}".format(json_path.resolve()))
+                raise err
+            except UnicodeDecodeError as err:
+                logger.error(
+                    "Failed to decode JSON file with encoding '{}': {}. "
+                    "Trying to use the fallback encoding...".format(
+                        self.ENCODING_DEFAULT, json_path.resolve()
+                    )
+                )
+                # switch to fallback encoding
+                self.ENCODING_DEFAULT = self.ENCODING_FALLBACK
+
+                if self.ENCODING_DEFAULT != self.ENCODING_FALLBACK:
+                    return self.check_json_file(json_path=json_path)
+
+                raise err
 
         # return sanitized path
         return json_path
